function [c,p,tx,scale]= tdic(x,y,ifz,ntime,nct,it)
% [c,p,tx,scale]= tdic(x,y,ifz,ntime,nct,it)
% Input
% x is the time series of the first variable
% y is the time series of the second variable
% ifz is the instantaneous period provided by the zero-crossing method
%     it is the output of the function maxlocalperiod
% ntime is the maximum window size, the default value is half of the length
% of the data
% nct is the maximum size of moving  time window
% - it: definition of degree of freedom
% -    0: means default, i.e., d.o.f. = n-2
% -    1: means how many cycles included in the region
% Output
% c is the correlation matrix
% p is the indicator for student-test
% tx is the time axis
% scale is the time scale
%
% [c,p,tx,scale]=tdicnew(x,y,pp);

% To show the result: surf(tx,scale,(c.*p))

% Written by Yongxiang HUANG 04-2012


%check input

Nx=length(x);
Ny=length(y);
if Nx~=Ny
    error('Length of the first two inputs should be the same.');
end

if nargin==3
    ntime=Nx;
    nct=fix(ntime/2);
    it=0;
end


if ntime>Nx
    ntime=Nx;
end


if (real(nct) > 0.5*ntime)
    ncct = fix(0.5*ntime);
else
    ncct = nct;
end

if nargin==5
    it=0;
end



c=zeros(ncct,ntime)*nan;%initial the output
p=c;
tx=zeros(1,ntime)*nan;

for j = 1:ntime
    d = max(fix(ifz(j)*0.5e0),1);
    if (d <=nct)
        
        for i = d:ncct
            if (j-i < 1 || j+i > ntime || j+i <= j-i)
                continue;
            end
            
            if (it == 0)
                df = ntime-2;
            else
                ndf = 0;
                
                for ii = j-i+1:j+i-1
                    if ( (x(ii-1) <= x(ii)) && (x(ii) >= x(ii+1)) )
                        ndf = ndf + 1;
                    end
                end
                if (ndf == 0)
                    continue;
                end
                df = ndf;
            end
            
            
            %%%%%
            out1=myxcorrc(x(j-i:j+i),y(j-i:j+i),double(df));%calculate the local correlation
            r=out1(1);
            z=out1(2);
            t=out1(3);
            
            prob=betai_s(0.5e0*df,0.5e0,df/(df+t.^22));    % student's t probability.
            %%%%%
            
            c(i,j) = r;
            p(i,j) = prob;
            tx(j)=j;
            if (it > 0) % we do not use this part
                t = sqrt(1.d0 - r*r);
                if (t == 0.d0)
                    t = t+0.000001d0;
                end
                t = r*sqrt(df)/t;
                p(i,j) = studentc(t,df);
            end
        end
    end
end
p(abs(p)>0.5)=nan; % check the student test
p(abs(p)<0.5)=1;
c(c>1)=nan; %check the correlation matrix
c(c==0)=nan;
scale=1:size(p,1);

